# -*- coding: utf-8 -*-
"""
Limon test suit

Copyright (C) 2005 Nir Soffer <nirs@freeshell.org>

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
"""

import unittest
import limon


class TranslateNonExisting(unittest.TestCase):

    def test(self):
        """ translate non exiting term """
        self.assertEqual(limon.translate('__foo__'), [])


class TranslateEnglishTerm(unittest.TestCase):
    
    def setUp(self):
        self.result = limon.translate('word')
    
    def testEnglish(self):
        """ translate English: English term """
        self.failUnless('word' in self.result[0]['en'])

    def testHebrew(self):
        """ translate English: Hebrew term """
        self.failUnless('מילה' in self.result[0]['he'])
        
    def testMeaning(self):
        """ translate English: meaning """
        self.failUnless(self.result[0]['meaning']) 


class TranslateHebrewTerm(unittest.TestCase):
    
    def setUp(self):
        self.result = limon.translate('מילה')
    
    def testEnglish(self):
        """ translate Hebrew: English term """
        self.failUnless('word' in self.result[0]['en'])

    def testHebrew(self):
        """ translate Hebrew: Hebrew term """
        self.failUnless('מילה' in self.result[0]['he'])
        
    def testMeaning(self):
        """ translate Hebrew: meaning """
        self.failUnless(self.result[0]['meaning']) 


class TranslateMultipleResults(unittest.TestCase):
    
    def test(self):
        """ translate terms with multiple results 
        
        Currently there are 3 entries for לוח.
        """
        translations = limon.translate('לוח')
        self.failUnless(len(translations) >= 3)

        
if __name__ == '__main__':
    suite = unittest.defaultTestLoader.loadTestsFromName(__name__)
    unittest.TextTestRunner(verbosity=2).run(suite)
    
        